# import the setuptools
from setuptools import setup, find_packages
from pathlib import Path

# Read the contents of README file
source_root = Path(".")
with (source_root / "README.md").open(encoding="utf-8") as f:
    long_description = f.read()
    
# Read the requirements
with (source_root / "requirements.txt").open(encoding="utf8") as f:
    requirements = f.readlines()

version = "0.1.1"

with (source_root / "src" / "diffusion_sde" / "version.py").open("w", encoding="utf-8") as f:
    f.writelines(
        [
            '"""This file is auto-generated by setup.py, please do not alter."""\n',
            f'__version__ = "{version}"\n',
            "",
        ]
    )

setup(
    name="diffusion-sde",
    version=version,
    description="Use score-based generative models to generate new images.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Ishan-phys/Diffusion-SDE.git",
    author="Ishan Srivastava",
    author_email="ishan.alld@gmail.com",
    
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Topic :: Software Development :: Build Tools",
        "License :: OSI Approved :: MIT License",
        "Environment :: Console",
        "Operating System :: OS Independent",
        "Intended Audience :: Science/Research",
        "Intended Audience :: Developers",
        "Topic :: Scientific/Engineering",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
    ],
    keywords="generative modelling, SDE, diffusion models",
    package_dir={'':"src"},
    packages=find_packages("src"),
    python_requires=">=3.7",
    license="MIT",
    install_requires=requirements,
    include_package_data=True,
    options={"bdist_wheel": {"universal": True}},
)